{ pkgs, lib, config, ... }: {

  imports = [ ./x11.nix ./audio.nix ];

  #networking.networkmanager.enable = true;
  #networking.wireless.enable = false;

  # configuration
  environment.extraInit = ''
    # use vi shortcuts
    # ----------------
    set -o vi
    EDITOR=vim
  '';

  services.xserver.displayManager.sessionCommands = ''
    ${pkgs.mumble}/bin/mumble mumble://name@lassul.us/party/hard &
    ${pkgs.vlc}/bin/vlc &
    ${pkgs.pavucontrol}/bin/pavucontrol &
  '';

  networking.hostName = "translate";
  nixpkgs.config.allowUnfree = true;

  programs.bash = {
    enableCompletion = true;
    interactiveShellInit = ''
      HISTCONTROL='erasedups:ignorespace'
      HISTSIZE=65536
      HISTFILESIZE=$HISTSIZE

      shopt -s checkhash
      shopt -s histappend histreedit histverify
      shopt -s no_empty_cmd_completion
      complete -d cd
    '';
    promptInit = ''
      if test $UID = 0; then
        PS1='\[\033[1;31m\]\w\[\033[0m\] '
        PROMPT_COMMAND='echo -ne "\033]0;$$ $USER@$PWD\007"'
      elif test $UID = 1337; then
        PS1='\[\033[1;32m\]\w\[\033[0m\] '
        PROMPT_COMMAND='echo -ne "\033]0;$$ $PWD\007"'
      else
        PS1='\[\033[1;33m\]\u@\w\[\033[0m\] '
        PROMPT_COMMAND='echo -ne "\033]0;$$ $USER@$PWD\007"'
      fi
      if test -n "$SSH_CLIENT"; then
        PS1='\[\033[35m\]\h'" $PS1"
        PROMPT_COMMAND='echo -ne "\033]0;$$ $HOSTNAME $USER@$PWD\007"'
      fi
    '';
  };

}
