{ config, lib, pkgs, ... }:
let
  nextcloudSync = folder:
    let
      password = "$( ${pkgs.pass}/bin/pass show home/nextcloud/palo/nextcloudcmd-token )";
      user = "palo";
    in
    pkgs.writers.writeBashBin "nextcloud-sync-${folder}" ''
      ${pkgs.nextcloud-client}/bin/nextcloudcmd \
        --path "${folder}" \
        ~/Nextcloud/${folder} \
        "https://${user}:${password}@nextcloud.ingolf-wagner.de"
    '';


in
{
  environment.systemPackages = with pkgs; [

    easytag
    dconf

    ((ganttproject-bin.override {
      jre = pkgs.openjdk11;
    }).overrideAttrs (old: {
      version = "3.1.3100";
      src = pkgs.fetchzip {
        url = "https://dl.ganttproject.biz/ganttproject-3.1.3100/ganttproject-3.1.3100.zip";
        sha256 = "sha256-hw2paak0P670/kemiuqYHIaN0uUtkVKy+AX2X7OdnJ4=";
      };
    }))

    autorandr

    (nextcloudSync "InstantUpload")
    (nextcloudSync "Pictures")
    (nextcloudSync "Unterlagen")
    (nextcloudSync "Nähen")
    (nextcloudSync "Video")
    (nextcloudSync "Kunstbuch")
    (nextcloudSync "AWS-SolutionArchitect-Professional")

    (pkgs.writeShellScriptBin "nixFlakes" ''
      exec ${pkgs.nixUnstable}/bin/nix --experimental-features "nix-command flakes" "$@"
    '')

    valentina

    signal-desktop

    sweethome3d.application
    pkgs.polygon-art.polygon-art

    # bluetooth gui
    blueberry

    nextcloud-client
    #gimp
    inkscape
    imagemagick

    bitwig-studio3
    #sononym-crawler
    darktable

    #blender
    mosquitto
    (pkgs.writers.writeBashBin "mqtt-tail" ''
      ${pkgs.mosquitto}/bin/mosquitto_sub -v \
               -h pepe.private \
               -u homeassistant \
               -P password \
               -t "#"
    '')

    # rust development environment
    rustup
    jetbrains.clion

    # general
    jetbrains.idea-ultimate
    #vscode

    # python
    python3Full
    jetbrains.pycharm-professional
    jetbrains.datagrip

    # matrix clients
    # --------------
    #element-desktop
    #fractal
    #legacy_2205.mirage-im
    #cinny-desktop
    fluffychat

    tor-browser-bundle-bin
    #(tor-browser-bundle-bin.overrideAttrs (old: rec {
    #  version = "11.0.1";
    #  name = "tor-browser-bundle-${version}";
    #  src = pkgs.fetchurl {
    #    url =
    #      "https://dist.torproject.org/torbrowser/10.0.15/tor-browser-linux64-10.0.15_en-US.tar.xz";
    #      "https://dist.torproject.org/torbrowser/11.0.1/tor-browser-linux64-11.0.1_en-US.tar.xz";
    #    sha256 = "1ah69jmfgik063f9gkvyv9d4k706pqihmzc4k7cc95zyd17v8wrs";
    #  };
    #}))

    sops

    steam-run

    bitwarden
    unstable.trilium-desktop
    nginx-config-formatter
    pre-commit

    sensu-go-cli
    yq-go

    unstable.yt-dlp

    unstable.terragrunt
    unstable.terraform
    terraform-docs

  ];

  home-manager.users.mainUser = {
    programs.obs-studio.enable = true;
  };

}
