{ config, pkgs, lib, ... }: {

  imports = [

    ../../components
    ../../system/desktop
    ../../system/server/netdata.nix

    ./hardware-configuration.nix
    ./packages.nix
    ./syncthing.nix
    ./tinc.nix

    #./wifi-access-point.nix
    #./wireshark.nix
    ./scanner.nix
    ./qemu.nix
    ./wireguard.nix

  ];

  components.gui.enable = true;

  services.nginx.enable = true;

  #sops.defaultSopsFile = ../../secrets/sterni.yaml;
  networking.hostName = "sterni";

  system.custom.wifi.interfaces = [ "wlp3s0" ];

  security.wrappers = {
    pmount = {
      source = "${pkgs.pmount}/bin/pmount";
      setuid = true;
      owner = "root";
      group = "root";
    };
    pumount = {
      source = "${pkgs.pmount}/bin/pumount";
      setuid = true;
      owner = "root";
      group = "root";
    };
  };

  programs.custom.steam.enable = true;
  programs.custom.video.enable = false;

  services.printing.enable = true;

  home-manager.users.mainUser.home.stateVersion = "22.11";

  # fonts
  # -----
  programs.custom.urxvt.fontSize = 12;
  programs.custom.xterm.fontSize = 12;

  virtualisation = {
    docker.enable = true;
    podman.enable = true;

    virtualbox = {
      host.enable = false;
      guest.x11 = false;
      guest.enable = false;
    };
  };

  configuration.desktop = {
    width = 1366;
    height = 768;
  };

  services.xserver.desktopManager.gnome.enable = true;

  custom.samba-share = {
    enable = false;
    folders = {
      share = "/home/share";
      video = "/home/video-material";
    };
  };

  # enable this to use sidequest
  programs.adb.enable = true;
  users.users.mainUser.extraGroups = [ "adbusers" "video" ];

  # for congress and streaming
  hardware.opengl = {
    enable = true;
    #  extraPackages = [
    #        intel-media-driver # LIBVA_DRIVER_NAME=iHD
    #        vaapiIntel         # LIBVA_DRIVER_NAME=i965 (older but works better for Firefox/Chromium)
    #        vaapiVdpau
    #        libvdpau-va-gl
    #  ];
    driSupport = true;
    driSupport32Bit = true;
  };
  #nixpkgs.config.packageOverrides = pkgs: {
  #  vaapiIntel = pkgs.vaapiIntel.override { enableHybridCodec = true; };
  #};

}
